herosdevices.hardware.dummy.electronics - Heros Devices 0.10.3 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.dummy.electronics

Dummy low level electronics for use in testing. Do not use in production.

## Module Contents

class herosdevices.hardware.dummy.electronics.RFSourceDummy

  Bases: `herosdevices.interfaces.atomiq.RFSource`

  Dummy class implementing an atomiq compatible RF source.

  frequency: float = 1000000.0
  amplitude: float = 0.1
  phase: float = 0.0
  freq_max: float = 100000000.0
  freq_min: float = 100000.0
  amp_max: float = 1.0
  amp_min: float = 0.0
  default_ramp_steps: int = 30
  blind: bool = False

class herosdevices.hardware.dummy.electronics.VoltageSourceDummy

  Bases: `herosdevices.interfaces.atomiq.VoltageSource`

  Dummy class implementing an atomiq compatible voltage source.

  min_voltage: float
  max_voltage: float
  default_ramp_steps: int = 30
  blind: bool = False

class herosdevices.hardware.dummy.electronics.CurrentSourceDummy

  Bases: `herosdevices.interfaces.atomiq.CurrentSource`

  Dummy class implementing an atomiq compatible current source.

  min_current: float
  max_current: float
  default_ramp_steps: int = 30
  blind: bool = False

class herosdevices.hardware.dummy.electronics.ADCChannelDummy

  Bases: `herosdevices.interfaces.atomiq.ADCChannel`

  Dummy class implementing a single atomiq compatible ADC channel.

  measure(samples: int = 1, cached: bool = False, channel: str = '') → float

    ‘Meaure’ a fake voltage.

class herosdevices.hardware.dummy.electronics.SwitchDummy

  Bases: `herosdevices.interfaces.atomiq.Switch`

  Dummy class implementing an atomiq compatible switch.

  on() → None

    Set the switch state to True.

  off() → None

    Set the switch state to False.

  is_on() → bool

    Return the current switch state.